import { navbar } from '../../../../../utils/navbar.js';
import { readFile } from 'fs/promises';
import { permissionBits, checkPermissions } from '../../../../../utils/permissions.js';

export default {
    path: "/dashboard/contacts/list",
    requiresLogin: true,
    permissions: permissionBits.CONTACTS | permissionBits.ADMIN,
    type: "get",
    async execute(request, response) {
        const contactList = await global.database.contacts.findAll();
        const contactTable = genContactTable(contactList);
        const html = await readFile(`${process.env.WWW}/dashboard/contacts/list.html`);            
        return await response.send(html.toString()
            .replace('<NAVBAR>', navbar(request.session))
            .replace('<CONTACTTABLE>', contactTable)
        );
    },
}

function genContactTable(contacts) {
    let res = `
      <table>
        <tr>
          <th>Téléphone</th>
          <th>Prénom</th>
          <th>Nom</th>
          <th>Status</th>
          <th>Action</th>
        </tr>`;
    for(const contact of contacts) {
        const [text, color] = statusText(contact.called, contact.vote);
        res += `
        <tr>
          <td>${contact.phone}</td>
          <td>${contact.firstName}</td>
          <td>${contact.lastName}</td>
          <td class="${color}">${text}</td>
          <td><button onclick="deleteContact('${contact.phone}');">Supprimer</button></td>
        </tr>`;
    }
    res += `</table>`;
    return res
}

function statusText(called, vote) {
    if(called == 0) return ["À appeler", "called_0"];
    else if(called == 2) return ["Appel en cours", ""];
    else if(vote==0) return ["Ne votera pas", "voted_0"];
    else if(vote==1) return ["Votera", "voted_1"];
    return "";
}
