import {
    permissionBits,
    checkPermissions,
} from "../../../../../utils/permissions.js";
import { readFile } from "fs/promises";
import { navbar } from "../../../../../utils/navbar.js";

export default {
    path: "/dashboard/users/:username",
    requiresLogin: true,
    permissions: permissionBits.USERS | permissionBits.ADMIN,
    type: "get",
    async execute(request, response) {
        const { username } = request.params;
        const user = await global.database.users.findOne({
            where: { username: username },
        });
        if (!user) return response.redirect("/dashboard/users");
        const html = await readFile(
            `${process.env.WWW}/dashboard/users/info.html`,
        );
        response.send(
            html
                .toString()
                .replace("<NAVBAR>", navbar(request.session))
                .replace("<USERINFO>", getUserHTML(user)),
        );
    },
};

function getUserHTML(user) {
    const userPermDict = checkPermissions(user.permissions);
    let userPerms = [];
    for (const [key, value] of Object.entries(userPermDict)) {
        if (value && key != "default") userPerms.push(key);
    }
    let res = `
      <table>
        <tr>
          <th>Identifiant</th>
          <th>Permissions</th>
          <th>Action</th>
        </tr>
        <tr>
          <td>${user.username}</td>
          <td>${userPerms.join(", ")}</td>
          <td><button onclick="deleteUser('${user.username}');">Supprimer</button></td>
        </tr>
      </table>
      
      <form action="javascript:editUserFromForm()" id="userEditForm">
        <div class="container">
          <hr>
          <p>Formulaire de modification de compte.</p>

          <label for="username"><b>Changer le nom d'utilisateur</b></label>
          <input type="text" placeholder="Entrez le nom d'utilisateur" name="username" id="username" value="${user.username}" required>
          <input type="hidden" name="oldName" value="${user.username}" required>

          <h4>Permissions</h4>
          <label class="container">Appels
            <input type="checkbox" name="permissions" value="2" ${(user.permissions & 2) != 0 ? "checked" : ""}>
            <span class="checkmark"></span>
          </label>
          <label class="container">Gestion des utilisateurs
            <input type="checkbox" name="permissions" value="4" ${(user.permissions & 4) != 0 ? "checked" : ""}>
            <span class="checkmark"></span>
          </label>
          <label class="container">Gestion des contacts
            <input type="checkbox" name="permissions" value="16" ${(user.permissions & 16) != 0 ? "checked" : ""}>
            <span class="checkmark"></span>
          </label>
          <label class="container">Admin
            <input type="checkbox" name="permissions" value="8" ${(user.permissions & 8) != 0 ? "checked" : ""}>
            <span class="checkmark"></span>
          </label>
          <hr>

          <button type="submit" class="registerbtn">Submit</button>
        </div>
      </form>`;
    return res;
}
